package cn.iocoder.yudao.module.wealth.controller.admin.receivable;

import cn.iocoder.yudao.framework.common.pojo.CommonResult;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.wealth.convert.receivableDiscount.ReceivableDiscountConvert;
import cn.iocoder.yudao.module.wealth.dal.dataobject.receivableDiscount.ReceivableDiscountDO;
import cn.iocoder.yudao.module.wealth.dal.mysql.receivableDiscount.ReceivableDiscountMapper;
import cn.iocoder.yudao.module.wealth.service.receivable.ReceivableService;
import cn.iocoder.yudao.module.wealth.vo.receivable.ReceivableBackVO;
import cn.iocoder.yudao.module.wealth.vo.receivable.ReceivableQueryVO;
import cn.iocoder.yudao.module.wealth.vo.receivable.ReceivableUpdateReqVO;
import cn.iocoder.yudao.module.wealth.vo.receivableDiscount.ReceivableDiscountBackVO;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.util.List;

import static cn.iocoder.yudao.framework.common.pojo.CommonResult.success;

@Validated
@RestController
@Api(tags = "管理后台 - 应收款")
@RequestMapping("/ecw/receivable")
public class ReceivableController {

    @Resource
    private ReceivableService receivableService;

    @Resource
    private ReceivableDiscountMapper receivableDiscountMapper;


    @GetMapping("/page")
    @ApiOperation("应收款分页列表")
    //@PreAuthorize("@ss.hasPermission('ecw:receivable:query')")
    public CommonResult<PageResult<ReceivableBackVO>> getReceivablePage(@Valid ReceivableQueryVO query, PageVO page) {
        PageResult<ReceivableBackVO> pageResult = receivableService.receivablePage(query, page);
        return success(pageResult);
    }

    @GetMapping("/getReceivableByOrderId")
    @ApiOperation("根据订单ID获取所有未加入收款单的应收明细")
    public CommonResult<List<ReceivableBackVO>> getReceivableByOrderId(@RequestParam("orderId") Long orderId) {
        return success(receivableService.getReceivableByOrderId(orderId));
    }

    @GetMapping("/get")
    @ApiOperation("获得应收款")
    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
    //@PreAuthorize("@ss.hasPermission('ecw:receivable:query')")
    public CommonResult<ReceivableBackVO> getReceivable(@RequestParam("id") Long id) {
        return success(receivableService.getReceivableBackVo(id));
    }


    @GetMapping("/getReceivableListByOrderId")
    @ApiOperation("根据订单ID获得应收款列表")
    @ApiImplicitParam(name = "id", value = "订单ID", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<List<ReceivableBackVO>> getReceivableListByOrderId(
            @RequestParam("id") Long id) {
        //lanbm 2024-06-20 添加注释
        return success(receivableService.getReceivableListByOrderId(id));
    }

    @GetMapping("/getFirstReceivableListByOrderId")
    @ApiOperation("根据订单ID获得需要预付应收款列表")
    @ApiImplicitParam(name = "id", value = "订单ID", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<List<ReceivableBackVO>> getFirstReceivableListByOrderId(@RequestParam("id") Long id) {
        return success(receivableService.getFirstReceivableListByOrderId(id));
    }

    @PostMapping("/updateReceivableDiscountById")
    @ApiOperation("根据应收ID更新应收优惠信息")
    public CommonResult<Boolean> updateReceivableDiscountById(@Valid @RequestBody ReceivableUpdateReqVO receivableUpdateReqVO) {
        receivableService.updateReceivableDiscountById(receivableUpdateReqVO);
        return success(true);
    }

    @GetMapping("/getReceivableDiscountLogById")
    @ApiOperation("得到应收优惠的最后操作人")
    @ApiImplicitParam(name = "id", value = "应收ID", required = true, example = "1024", dataTypeClass = Long.class)
    public CommonResult<ReceivableDiscountBackVO> updateReceivableDiscountById(@RequestParam("id") Long id) {
        LambdaQueryWrapper<ReceivableDiscountDO> lambdaQueryWrapper = new LambdaQueryWrapper<>();
        lambdaQueryWrapper.eq(ReceivableDiscountDO::getReceivableId, id);
        lambdaQueryWrapper.orderByDesc(ReceivableDiscountDO::getCreateTime);
        lambdaQueryWrapper.last("limit 1");
        return success(ReceivableDiscountConvert.INSTANCE.convert(receivableDiscountMapper.selectOne(lambdaQueryWrapper)));
    }

    /*
    @GetMapping("/list")
    @ApiOperation("根据id集合获得应收款列表")
    @ApiImplicitParam(name = "ids", value = "编号列表", required = true, example = "1024,2048", dataTypeClass = List.class)
    //@PreAuthorize("@ss.hasPermission('ecw:receivable:query')")
    public CommonResult<List<ReceivableBackVO>> receivableList(@RequestParam("ids") List<Long> ids) {
        List<ReceivableBackVO> list = receivableService.receivableList(ids);
        return success(list);
    }*/

    /*
    @GetMapping("/export-excel")
    @ApiOperation("导出应收款 Excel")
    //@PreAuthorize("@ss.hasPermission('ecw:receivable:export')")
    @OperateLog(type = EXPORT)
    public void exportReceivableExcel(@Valid ReceivableQueryVO query,
                                      HttpServletResponse response) throws IOException {
        List<ReceivableDO> list = receivableService.getReceivableList(query);
        // 导出 Excel
        List<ReceivableBackVO> datas = ReceivableConvert.INSTANCE.convertList(list);
        ExcelUtils.write(response, "应收款.xls", "数据", ReceivableBackVO.class, datas);
    }*/


    //    @PostMapping("/create")
//    @ApiOperation("创建应收款")
//    //@PreAuthorize("@ss.hasPermission('ecw:receivable:create')")
//    public CommonResult<Long> createReceivable(@Valid @RequestBody ReceivableCreateReqVO createReqVO) {
//        return success(receivableService.createReceivable(createReqVO));
//    }

//    @PutMapping("/update")
//    @ApiOperation("更新应收款")
//    //@PreAuthorize("@ss.hasPermission('ecw:receivable:update')")
//    public CommonResult<Boolean> updateReceivable(@Valid @RequestBody ReceivableUpdateReqVO updateReqVO) {
//        receivableService.updateReceivable(updateReqVO);
//        return success(true);
//    }

//    @DeleteMapping("/delete")
//    @ApiOperation("删除应收款")
//    @ApiImplicitParam(name = "id", value = "编号", required = true, example = "1024", dataTypeClass = Long.class)
//    //@PreAuthorize("@ss.hasPermission('ecw:receivable:delete')")
//    public CommonResult<Boolean> deleteReceivable(@RequestParam("id") Long id) {
//        receivableService.deleteReceivable(id);
//        return success(true);
//    }
}
